window.Gleam.initSearch([{"doc":"unchained","title":"unchained","content":"# unchained\n\n[![Package Version](https://img.shields.io/hexpm/v/unchained)](https://hex.pm/packages/unchained)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/unchained/)\n\n```sh\ngleam add unchained\n```\n\n```gleam\nimport unchained\n\npub fn main() {\n  let tool =\n    unchained.Tool(\n      name: &quot;format&quot;,\n      description: &quot;Format the translation&quot;,\n      function: fn(x) { Ok(string.uppercase(x)) },\n    )\n\n  let config =\n    unchained.LLMConfig(\n      base_url: &quot;localhost:11434&quot;,\n      model: &quot;llama3.2:3b&quot;,\n      temperature: 0.0,\n    )\n\n  let chain =\n    unchained.new()\n    |&gt; unchained.add_prompt_template(\n      &quot;Translate this to {{ language }}: {{ input }}\n    Just reply with the translation, do not include any explanation. Make sure to format the answer first.\n\n    Here is the list of tools available to use:\n    {{#each tools}}\n      Function Name: {{name}}\n      Function Description: {{description}}\n      ---\n    {{/each}}\n\n    To use too call it with:\n    Tool Selected: &lt;tool name&gt;\n    &quot;,\n      [&quot;language&quot;, &quot;input&quot;],\n      [unchained.ToolSelector(fn(_) { Some(&quot;&quot;) }, tool)],\n    )\n    |&gt; should.be_ok()\n    |&gt; unchained.set_variable(&quot;language&quot;, &quot;French&quot;)\n    |&gt; unchained.add_llm(config)\n    |&gt; unchained.add_tool(tool)\n\n  // Run the chain\n  unchained.run(config, chain, &quot;lost bread&quot;)\n  |&gt; should.be_ok()\n  |&gt; should.equal(&quot;PAIN PERDU&quot;)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/unchained&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"unchained","title":"Chain","content":"pub type Chain {\n  Chain(steps: List(ChainStep), memory: Memory)\n}\n\nChain(steps: List(ChainStep), memory: Memory)\n\n\nSynonyms:\nunchained.Chain\nunchained Chain","url":"unchained.html#Chain"},{"doc":"unchained","title":"ChainStep","content":"pub type ChainStep {\n  LLMStep(llm_config: LLMConfig)\n  ToolStep(tool: Tool)\n  PromptTemplate(\n    template: handles.Template,\n    tools: List(TooSelector),\n  )\n  ChainBreaker(should_stop: fn(String) -&gt; Option(String))\n}\n\nLLMStep(llm_config: LLMConfig)\n\n\nToolStep(tool: Tool)\n\n\nPromptTemplate(\n  template: handles.Template,\n  tools: List(TooSelector),\n)\n\n\nChainBreaker(should_stop: fn(String) -&gt; Option(String))\n\n\nSynonyms:\nunchained.ChainStep\nunchained ChainStep","url":"unchained.html#ChainStep"},{"doc":"unchained","title":"Error","content":"pub type Error {\n  ChainError(String)\n  LLMError(String)\n  HTTPError(String)\n}\n\nChainError(String)\n\n\nLLMError(String)\n\n\nHTTPError(String)\n\n\nSynonyms:\nunchained.Error\nunchained Error","url":"unchained.html#Error"},{"doc":"unchained","title":"HistoryEntry","content":"pub type HistoryEntry {\n  HistoryEntry(input: String, output: String, timestamp: Time)\n}\n\nHistoryEntry(input: String, output: String, timestamp: Time)\n\n\nSynonyms:\nunchained.HistoryEntry\nunchained HistoryEntry","url":"unchained.html#HistoryEntry"},{"doc":"unchained","title":"LLMConfig","content":"pub type LLMConfig {\n  LLMConfig(host: String, model: String, temperature: Float)\n}\n\nLLMConfig(host: String, model: String, temperature: Float)\n\n\nSynonyms:\nunchained.LLMConfig\nunchained LLMConfig","url":"unchained.html#LLMConfig"},{"doc":"unchained","title":"LLMResponse","content":"pub type LLMResponse {\n  Response(response: String)\n}\n\nResponse(response: String)\n\n\nSynonyms:\nunchained.LLMResponse\nunchained LLMResponse","url":"unchained.html#LLMResponse"},{"doc":"unchained","title":"Memory","content":"pub type Memory {\n  Memory(\n    variables: Dict(String, String),\n    history: List(HistoryEntry),\n  )\n}\n\nMemory(\n  variables: Dict(String, String),\n  history: List(HistoryEntry),\n)\n\n\nSynonyms:\nunchained.Memory\nunchained Memory","url":"unchained.html#Memory"},{"doc":"unchained","title":"TooSelector","content":"pub type TooSelector {\n  ToolSelector(select: fn(String) -&gt; Option(String), tool: Tool)\n}\n\nToolSelector(select: fn(String) -&gt; Option(String), tool: Tool)\n\n\nSynonyms:\nunchained.TooSelector\nunchained TooSelector","url":"unchained.html#TooSelector"},{"doc":"unchained","title":"Tool","content":"pub type Tool {\n  Tool(\n    name: String,\n    description: String,\n    function: fn(String) -&gt; Result(String, Error),\n  )\n}\n\nTool(\n  name: String,\n  description: String,\n  function: fn(String) -&gt; Result(String, Error),\n)\n\n\nSynonyms:\nunchained.Tool\nunchained Tool","url":"unchained.html#Tool"},{"doc":"unchained","title":"add_llm","content":"pub fn add_llm(chain: Chain, llm_config: LLMConfig) -&gt; Chain\n\nSynonyms:\nunchained.add_llm\nunchained add_llm","url":"unchained.html#add_llm"},{"doc":"unchained","title":"add_prompt_template","content":"pub fn add_prompt_template(\n  chain: Chain,\n  template_str: String,\n  tools: List(TooSelector),\n) -&gt; Result(Chain, TokenizerError)\n\nSynonyms:\nunchained.add_prompt_template\nunchained add_prompt_template","url":"unchained.html#add_prompt_template"},{"doc":"unchained","title":"add_tool","content":"pub fn add_tool(chain: Chain, tool: Tool) -&gt; Chain\n\nSynonyms:\nunchained.add_tool\nunchained add_tool","url":"unchained.html#add_tool"},{"doc":"unchained","title":"new","content":"pub fn new() -&gt; Chain\n\nSynonyms:\nunchained.new\nunchained new","url":"unchained.html#new"},{"doc":"unchained","title":"run","content":"pub fn run(chain: Chain, input: String) -&gt; Result(String, Error)\n\nSynonyms:\nunchained.run\nunchained run","url":"unchained.html#run"},{"doc":"unchained","title":"run_with","content":"pub fn run_with(\n  chain: Chain,\n  input: String,\n  llm_engine: fn(String, LLMConfig) -&gt; Result(LLMResponse, Error),\n) -&gt; Result(String, Error)\n\nSynonyms:\nunchained.run_with\nunchained run_with","url":"unchained.html#run_with"},{"doc":"unchained","title":"set_variable","content":"pub fn set_variable(\n  chain: Chain,\n  key: String,\n  value: String,\n) -&gt; Chain\n\nSynonyms:\nunchained.set_variable\nunchained set_variable","url":"unchained.html#set_variable"},{"doc":"unchained","title":"unchained","content":"","url":"unchained.html"}]);